@@ -3,6 +3,7 @@ package Module::Starter;
 use warnings;
 use strict;
 use Carp qw( croak );
+use Module::Runtime qw( require_module );
 
 =head1 NAME
 
@@ -10,11 +11,11 @@ Module::Starter - a simple starter kit for any module
 
 =head1 VERSION
 
-Version 1.72
+Version 1.74
 
 =cut
 
-our $VERSION = '1.72';
+our $VERSION = '1.74';
 
 =head1 SYNOPSIS
 
@@ -91,9 +92,7 @@ sub import {
     my $parent;
 
     while (my $child = shift @plugins) {
-        eval "require $child";
-
-        croak "couldn't load plugin $child: $@" if $@;
+        require_module $child;
 
         ## no critic
         no strict 'refs'; #Violates ProhibitNoStrict
@@ -170,6 +169,30 @@ Copyright 2010 Sawyer X, All Rights Reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<mbtiny>
+
+Minimal authoring tool to create and manage distributions using
+L<Module::Build::Tiny> as an installer.
+
+=item L<Dist::Milla>
+
+Easy to use and powerful authoring tool using L<Dist::Zilla> to create and
+manage distributions.
+
+=item L<Minilla>
+
+Authoring tool similar to L<Dist::Milla> but without using L<Dist::Zilla>.
+
+=item L<Dist::Zilla>
+
+Very complex, fully pluggable and customizable distribution builder.
+
+=back
+
 =cut
 
 1;
