@@ -11,11 +11,11 @@ Module::Starter::BuilderSet - determine builder metadata
 
 =head1 VERSION
 
-Version 1.72
+Version 1.74
 
 =cut
 
-our $VERSION = '1.72';
+our $VERSION = '1.74';
 
 =head1 SYNOPSIS
 
@@ -111,7 +111,7 @@ sub _builder {
 
     unless (exists $self->{$builder}) {
         carp("Don't know anything about builder '$builder'.");
-        return;
+        return undef;
     }
 
     return $self->{$builder};
